@@ -12,7 +12,6 @@
 
 -module(chttpd_util).
 
-
 -export([
     get_chttpd_config/1,
     get_chttpd_config/2,
@@ -22,46 +21,53 @@
     get_chttpd_auth_config/2,
     get_chttpd_auth_config_integer/2,
     get_chttpd_auth_config_boolean/2,
-    maybe_add_csp_header/3
+    maybe_add_csp_header/3,
+    get_db_info/1
 ]).
 
-
 get_chttpd_config(Key) ->
     config:get("chttpd", Key, config:get("httpd", Key)).
 
-
 get_chttpd_config(Key, Default) ->
     config:get("chttpd", Key, config:get("httpd", Key, Default)).
 
-
 get_chttpd_config_integer(Key, Default) ->
-    config:get_integer("chttpd", Key,
-        config:get_integer("httpd", Key, Default)).
-
+    config:get_integer(
+        "chttpd",
+        Key,
+        config:get_integer("httpd", Key, Default)
+    ).
 
 get_chttpd_config_boolean(Key, Default) ->
-    config:get_boolean("chttpd", Key,
-        config:get_boolean("httpd", Key, Default)).
-
+    config:get_boolean(
+        "chttpd",
+        Key,
+        config:get_boolean("httpd", Key, Default)
+    ).
 
 get_chttpd_auth_config(Key) ->
     config:get("chttpd_auth", Key, config:get("couch_httpd_auth", Key)).
 
-
 get_chttpd_auth_config(Key, Default) ->
-    config:get("chttpd_auth", Key,
-        config:get("couch_httpd_auth", Key, Default)).
-
+    config:get(
+        "chttpd_auth",
+        Key,
+        config:get("couch_httpd_auth", Key, Default)
+    ).
 
 get_chttpd_auth_config_integer(Key, Default) ->
-    config:get_integer("chttpd_auth", Key,
-        config:get_integer("couch_httpd_auth", Key, Default)).
-
+    config:get_integer(
+        "chttpd_auth",
+        Key,
+        config:get_integer("couch_httpd_auth", Key, Default)
+    ).
 
 get_chttpd_auth_config_boolean(Key, Default) ->
-    config:get_boolean("chttpd_auth", Key,
-        config:get_boolean("couch_httpd_auth", Key, Default)).
-
+    config:get_boolean(
+        "chttpd_auth",
+        Key,
+        config:get_boolean("couch_httpd_auth", Key, Default)
+    ).
 
 maybe_add_csp_header(Component, OriginalHeaders, DefaultHeaderValue) ->
     Enabled = config:get_boolean("csp", Component ++ "_enable", true),
@@ -95,3 +101,12 @@ handle_legacy_config(OriginalHeaders, DefaultHeaderValue) ->
         false ->
             OriginalHeaders
     end.
+
+get_db_info(DbName) ->
+    Timeout = fabric_util:request_timeout(),
+    IsolatedFun = fun() -> fabric:get_db_info(DbName) end,
+    try
+        fabric_util:isolate(IsolatedFun, Timeout)
+    catch
+        _Tag:Error -> {error, Error}
+    end.
